Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(267)

Unified Diff: src/pdf/SkPDFDevice.h

Issue 1035513003: SkPDF: skpdfdocument and skpdfpage use skpdfdevice in a const way (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: rebase Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/doc/SkDocument_PDF.cpp ('k') | src/pdf/SkPDFDevice.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/pdf/SkPDFDevice.h
diff --git a/src/pdf/SkPDFDevice.h b/src/pdf/SkPDFDevice.h
index a90ea115c1b69951e0a48f9dd1e7961a1c5f6329..425362f7058e8b149ea382dd2f93910829cadb24 100644
--- a/src/pdf/SkPDFDevice.h
+++ b/src/pdf/SkPDFDevice.h
@@ -35,7 +35,6 @@ class SkPDFResourceDict;
class SkPDFShader;
class SkPDFStream;
class SkRRect;
-template <typename T> class SkTSet;
// Private classes.
struct ContentEntry;
@@ -138,9 +137,9 @@ public:
// PDF specific methods.
/** Returns the resource dictionary for this device.
*/
- SkPDFResourceDict* getResourceDict();
+ SkPDFResourceDict* createResourceDict() const;
/** Get the fonts used on this device.
*/
@@ -150,7 +149,7 @@ public:
* @param dict Dictionary to add destinations to.
* @param page The PDF object representing the page for this device.
*/
- void appendDestinations(SkPDFDict* dict, SkPDFObject* page);
+ void appendDestinations(SkPDFDict* dict, SkPDFObject* page) const;
/** Returns a copy of the media box for this device. The caller is required
* to unref() this when it is finished.
@@ -198,7 +197,6 @@ private:
SkClipStack fExistingClipStack;
SkRegion fExistingClipRegion;
SkPDFArray* fAnnotations;
- SkPDFResourceDict* fResourceDict;
SkTDArray<NamedDestination*> fNamedDestinations;
SkTDArray<SkPDFGraphicState*> fGraphicStateResources;
« no previous file with comments | « src/doc/SkDocument_PDF.cpp ('k') | src/pdf/SkPDFDevice.cpp » ('j') | no next file with comments »
@@ -138,9 +137,9 @@ public:
// PDF specific methods.
- /** Returns the resource dictionary for this device.
+ /** Create the resource dictionary for this device.
*/

Powered by Google App Engine
This is Rietveld 408576698